@@ -8,6 +8,7 @@ import os
 from multiprocessing import  Process, Pool
 import urllib.parse as path_encoder
 import time
+import datetime
 
 
 HELLO_WORLD_MESSAGE = 'Hello world! PyOhio Demo - 3! CLEpy'
@@ -44,6 +45,7 @@ def create_training_job(local_data, source_code, weights, hyper_param):
     # upload data and code to s3
     # https://boto3.amazonaws.com/v1/documentation/api/latest/guide/s3-presigned-urls.html
     
+    start_time = datetime.datetime.now()
     if local_data is not None:
         if local_data.startswith('s3://'):
             with open("s3_public_dataset.txt", 'w') as f:
@@ -53,6 +55,8 @@ def create_training_job(local_data, source_code, weights, hyper_param):
         else:
             __upload_one_folder(job_id, FileType.Traindata.name, local_data)
             print(f"uploaded {local_data}")
+    end_time = datetime.datetime.now()
+    print("datasets upload time: %s Seconds"%(end_time-start_time))
     
 
     if source_code is not None:
@@ -117,7 +121,8 @@ def get_model(job_id, model):
 
 def get_training_job_logstream(job_id):
     url = f"{API_GW}/jobs/{job_id}"
-    #print(f"getting {url}")
+    print(f"getting {url}")
+
     tmp_status = ["Completed", "Failed", "Stopped"]
     headers = {
         'Content-Type': 'application/json'
@@ -125,12 +130,14 @@ def get_training_job_logstream(job_id):
     #print(f"reponse {response}")
     len_c = 0
     job_status = get_training_job_status(job_id)
-    #print(job_status)
     while True:
         response = requests.request("POST", url, headers=headers)
+
         contents = json.loads(response.text)
+
         len_cc = len(contents)
         #print(len_c,len_cc)
+
         if len_cc > len_c and len_cc!=2:
             #len_d = len_cc- len_c
             contents = contents[len_c:len_cc]
@@ -143,6 +150,7 @@ def get_training_job_logstream(job_id):
             print("waiting...")
         time.sleep(10)
         job_status = get_training_job_status(job_id)
+
         if job_status in tmp_status:
             break
     return response
@@ -230,10 +238,10 @@ if __name__ == "__main__":
     create_training_job("s3://code-devcloud/jobs/05ec9d2d-8862-49c1-9d1c-a39125e23fc2/Traindata/datasets_simple/",
                         "yolov5.tar",
                         "yolov5s.pt",
-                        {"instance_type":"ml.m5.xlarge",
+                        {"instance_type":"ml.p3.2xlarge",
                         "instance_count":"1",
                         "framework_version":"1.8.1",
-                        "hyperparameters":{"imgsz":"64", "epochs":"10"}})
+                        "hyperparameters":{"imgsz":"640", "epochs":"100"}})
     
     #make_tar("train.py")
     #s3://code-devcloud/jobs/090e3c81-804a-4a34-abfb-33d67d77bfa8/Traindata/mnist/
